# Unix SMB/CIFS samba-tool-plus command main module.

# Copyright (C) Paul Wolneykien <manowar@altlinux.org> 2017.
#
# Based on netcmd/main module by Jelmer Vernooij <jelmer@samba.org>.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The main samba-tool-plus command implementation."""

from samba import getopt as options
from samba.netcmd import SuperCommand
from samba.netcmd.main import cmd_sambatool
from netcmdplus.version import VersionOptions
from netcmdplus.user import cmd_userplus
from netcmdplus.group import cmd_groupplus

class cmd_sambatoolplus(cmd_sambatool):
    """Extended samba administration tool."""

    subcommands = cmd_sambatool.subcommands
    subcommands["user"] = cmd_userplus()
    subcommands["group"] = cmd_groupplus()

def samba_tool_plus(*args, **kwargs):
    """A single function that runs samba-tool-plus, returning an error code on
    error, and None on success."""
    try:
        cmd, argv = cmd_sambatoolplus()._resolve("samba-tool-plus", *args, **kwargs)
        ret = cmd._run(*argv)
    except SystemExit as e:
        ret = e.code
    except Exception as e:
        cmd.show_command_error(e)
        ret = 1
    return ret
